@@ -1,26 +1,44 @@
-from hestia_earth.schema import NodeType
-from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.tools import flatten
 
-from hestia_earth.validation.utils import _find_linked_node
+from hestia_earth.validation.utils import find_linked_node, find_by_product, find_by_unique_product
 from .shared import (
     validate_list_min_below_max, validate_region_in_country, validate_country, validate_is_region,
     validate_list_term_percent, validate_linked_source_privacy, validate_date_lt_today,
-    validate_list_model, validate_private_has_source, validate_list_value_between_min_max
+    validate_list_model, validate_private_has_source, validate_list_value_between_min_max, is_date_equal,
+    validate_other_model
 )
-from .indicator import validate_characterisedIndicator_model, validate_landTransformation
+from .indicator import (
+    validate_characterisedIndicator_model,
+    validate_landTransformation,
+    validate_inonising_compounds_waste
+)
+
+
+def validate_empty(impact_assessment: dict):
+    return any([
+        impact_assessment.get('cycle'),
+        impact_assessment.get('emissionsResourceUse', []),
+        len(impact_assessment.get('impacts', [])) > 0,
+        len(impact_assessment.get('endpoints', [])) > 0
+    ]) or {
+        'level': 'error',
+        'dataPath': '',
+        'message': 'should not be empty',
+        'params': {
+            'type': 'ImpactAssessment'
+        }
+    }
 
 
 def validate_linked_cycle_product(impact_assessment: dict, cycle: dict):
     product = impact_assessment.get('product', {})
-    product_id = product.get('@id')
-    has_product = find_term_match(cycle.get('products', []), product_id, None) is not None
-    return has_product or {
+    cycle_product = find_by_product(cycle, product) or find_by_unique_product(cycle, product)
+    return cycle_product is not None or {
         'level': 'error',
         'dataPath': '.product',
         'message': 'should be included in the cycle products',
         'params': {
-            'product': product,
+            'product': product.get('term', {}),
             'node': {
                 'type': 'Cycle',
                 'id': cycle.get('id', cycle.get('@id'))
@@ -29,33 +47,12 @@ def validate_linked_cycle_product(impact_assessment: dict, cycle: dict):
     }
 
 
-def _filter_same_cycle(cycle: dict):
-    def filter(impact_assessment: dict):
-        ia_cycle = impact_assessment.get('cycle', {})
-        return any([
-            ia_cycle.get('id') and ia_cycle.get('id') == cycle.get('id'),
-            ia_cycle.get('@id') and ia_cycle.get('@id') == cycle.get('@id')
-        ])
-    return filter
-
-
-def validate_single_linked_impact_assessment(impact_assessment: dict, node_map: dict, cycle: dict):
-    product = impact_assessment.get('product', {})
-    product_id = product.get('@id')
-    uploaded_impact_assessments = node_map.get(NodeType.IMPACTASSESSMENT.value).values()
-    related_impact_assessments = list(filter(_filter_same_cycle(cycle), uploaded_impact_assessments))
-    same_product_id = list(filter(lambda v: v.get('product', {}).get('@id') == product_id, related_impact_assessments))
-    return len(same_product_id) == 1 or {
+def validate_linked_cycle_endDate(impact_assessment: dict, cycle: dict):
+    key = 'endDate'
+    return is_date_equal(impact_assessment.get(key), cycle.get(key), True) or {
         'level': 'error',
-        'dataPath': '.product',
-        'message': 'multiple ImpactAssessment are associated with the same Product of the same Cycle',
-        'params': {
-            'product': product,
-            'node': {
-                'type': 'Cycle',
-                'id': cycle.get('id', cycle.get('@id'))
-            }
-        }
+        'dataPath': f".{key}",
+        'message': f"must be equal to the Cycle {key}"
     }
 
 
@@ -75,8 +72,9 @@ def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
     List
         The list of errors for the `ImpactAssessment`, which can be empty if no errors detected.
     """
-    cycle = _find_linked_node(node_map, impact_assessment.get('cycle', {}))
+    cycle = find_linked_node(node_map, impact_assessment.get('cycle', {}))
     return [
+        validate_empty(impact_assessment),
         validate_date_lt_today(impact_assessment, 'startDate'),
         validate_date_lt_today(impact_assessment, 'endDate'),
         validate_linked_source_privacy(impact_assessment, 'source', node_map),
@@ -85,25 +83,29 @@ def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
         validate_is_region(impact_assessment) if 'region' in impact_assessment else True,
         validate_region_in_country(impact_assessment) if 'region' in impact_assessment else True,
         validate_linked_cycle_product(impact_assessment, cycle) if cycle else True,
-        validate_single_linked_impact_assessment(impact_assessment, node_map, cycle) if cycle else True
+        validate_linked_cycle_endDate(impact_assessment, cycle) if cycle else True
     ] + flatten(
         ([
             validate_list_min_below_max(impact_assessment, 'emissionsResourceUse'),
             validate_list_value_between_min_max(impact_assessment, 'emissionsResourceUse'),
             validate_list_term_percent(impact_assessment, 'emissionsResourceUse'),
             validate_characterisedIndicator_model(impact_assessment, 'emissionsResourceUse'),
-            validate_landTransformation(impact_assessment, 'emissionsResourceUse')
+            validate_landTransformation(impact_assessment, 'emissionsResourceUse'),
+            validate_other_model(impact_assessment, 'emissionsResourceUse'),
+            validate_inonising_compounds_waste(impact_assessment, 'emissionsResourceUse'),
         ] if len(impact_assessment.get('emissionsResourceUse', [])) > 0 else []) +
         ([
             validate_list_min_below_max(impact_assessment, 'impacts'),
             validate_list_value_between_min_max(impact_assessment, 'impacts'),
             validate_list_term_percent(impact_assessment, 'impacts'),
             validate_list_model(impact_assessment, 'impacts'),
-            validate_characterisedIndicator_model(impact_assessment, 'impacts')
+            validate_characterisedIndicator_model(impact_assessment, 'impacts'),
+            validate_other_model(impact_assessment, 'emissionsResourceUse')
         ] if len(impact_assessment.get('impacts', [])) > 0 else []) +
         ([
             validate_list_min_below_max(impact_assessment, 'endpoints'),
             validate_list_value_between_min_max(impact_assessment, 'endpoints'),
-            validate_list_term_percent(impact_assessment, 'endpoints')
+            validate_list_term_percent(impact_assessment, 'endpoints'),
+            validate_other_model(impact_assessment, 'emissionsResourceUse')
         ] if len(impact_assessment.get('endpoints', [])) > 0 else [])
     )
