@@ -1,5 +1,6 @@
+import traceback
 from hestia_earth.schema import TermTermType, CycleFunctionalUnit
-from hestia_earth.utils.model import find_primary_product
+from hestia_earth.utils.model import find_primary_product, filter_list_term_type
 from hestia_earth.utils.lookup import get_table_value, download_lookup, column_name
 from hestia_earth.utils.tools import list_sum, flatten, non_empty_list
 from hestia_earth.distribution.posterior_yield import get_post
@@ -7,6 +8,8 @@ from hestia_earth.distribution.prior_yield import get_prior
 
 from hestia_earth.validation.log import logger
 from hestia_earth.validation.utils import _list_sum, _filter_list_errors
+from hestia_earth.validation.distribution import UNIVARIATE_DEFAULT_THRESHOLD, validate as validate_distribution
+from .shared import CROP_SITE_TYPE
 
 
 def validate_economicValueShare(products: list):
@@ -149,32 +152,8 @@ def validate_product_ha_functional_unit_ha(cycle: dict, list_key: str = 'product
         _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
 
 
-DEFAULT_THRESHOLD = 0.95
-DEFAULT_ZSCORE = 1.96
-CI_TO_ZSCORE = {
-    0.9: 1.65,
-    DEFAULT_THRESHOLD: DEFAULT_ZSCORE,
-    0.99: 2.58
-}
-
-
-def _get_mu_sd(country_id: str, product_id: str):
-    mu, sd = get_post(country_id, product_id)
-    return (mu, sd) if mu is not None else get_prior(country_id, product_id)
-
-
-def _validate_yield(country_id: str, product_id: str, yields: list[float], threshold: float = DEFAULT_THRESHOLD):
-    z = CI_TO_ZSCORE[threshold]
-    mu, sd = _get_mu_sd(country_id, product_id)
-    min = mu-(z*sd) if mu is not None else None
-    max = mu+(z*sd) if mu is not None else None
-    passes = [min <= y <= max if mu is not None else True for y in yields]
-    outliers = [y for y in yields if not min <= y <= max] if mu is not None else []
-    return all(passes), outliers, min, max
-
-
-def validate_product_yield(cycle: dict, site: dict, list_key: str = 'products', threshold: float = DEFAULT_THRESHOLD):
-    country_id = site.get('country', {}).get('@id')
+def _validate_product_yield(country: dict, list_key: str, threshold: float):
+    country_id = country.get('@id')
 
     def validate(values: tuple):
         index, product = values
@@ -182,23 +161,49 @@ def validate_product_yield(cycle: dict, site: dict, list_key: str = 'products',
         product_id = product.get('term', {}).get('@id')
         product_value = product.get('value', [])
 
-        valid, outliers, min, max = _validate_yield(country_id, product_id, product_value, threshold)
+        def _get_mu_sd():
+            mu, sd = get_post(country_id, product_id)
+            return (mu, sd) if mu is not None else get_prior(country_id, product_id)
+
+        valid, outliers, min, max = validate_distribution(product_value, threshold, get_mu_sd=_get_mu_sd)
         return valid or {
             'level': 'warning',
             'dataPath': f".{list_key}[{index}].value",
             'message': 'is outside confidence interval',
             'params': {
                 'term': product.get('term', {}),
-                'country': site.get('country', {}),
+                'country': country,
                 'outliers': outliers,
                 'threshold': threshold,
                 'min': min,
                 'max': max
             }
         }
+    return validate
+
+
+def validate_product_yield(
+    cycle: dict, site: dict, list_key: str = 'products', threshold: float = UNIVARIATE_DEFAULT_THRESHOLD
+):
+    country = site.get('country', {})
+    products = cycle.get(list_key, [])
 
     try:
-        return _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
-    except Exception as e:
-        logger.error(f"Error validating using distribution: '{str(e)}'")
+        return site.get('siteType') not in CROP_SITE_TYPE or (
+            _filter_list_errors(map(_validate_product_yield(country, list_key, threshold), enumerate(products)))
+        )
+    except Exception:
+        stack = traceback.format_exc()
+        logger.error(f"Error validating using distribution: '{stack}'")
         return True
+
+
+def validate_liveAnimal_requires_excreta(cycle: dict, list_key: str = 'products'):
+    products = cycle.get(list_key, [])
+    has_liveAnimal = len(filter_list_term_type(products, TermTermType.LIVEANIMAL)) > 0
+    has_excreta = len(filter_list_term_type(products, TermTermType.EXCRETA)) > 0
+    return not has_liveAnimal or has_excreta or {
+        'level': 'error',
+        'dataPath': f".{list_key}",
+        'message': 'must add an excreta product with a liveAnimal product'
+    }
