@@ -1,19 +1,33 @@
-import os
 from concurrent.futures import ThreadPoolExecutor
+from decimal import Decimal
 from functools import reduce
+from typing import List
 import re
+from hestia_earth.schema import TermTermType, SiteSiteType
 from hestia_earth.utils.api import download_hestia
-from hestia_earth.utils.tools import flatten, list_sum, safe_parse_float
-from hestia_earth.utils.lookup import download_lookup, get_table_value
-from hestia_earth.earth_engine.gee_utils import MAX_AREA_SIZE
+from hestia_earth.utils.model import filter_list_term_type
+from hestia_earth.utils.tools import flatten, list_sum, safe_parse_float, safe_parse_date, get_dict_key
+from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 
-from hestia_earth.validation.geojson import get_geojson_area
-from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id, get_region_size, get_boundary_size
-from hestia_earth.validation.utils import (
-    update_error_path, _filter_list_errors, _next_error, _value_average, _is_number,
-    _find_linked_node, _is_before_today, run_model_from_node, run_model, _value_from_model, _get_dict_key,
-    _list_except_item, _dict_without_key, _hash_dict, _value_range_error
+from hestia_earth.validation.gee import (
+    MAX_AREA_SIZE, is_enabled as gee_is_enabled, id_to_level, get_region_id, get_region_distance
 )
+from hestia_earth.validation.models import (
+    is_enabled as models_is_enabled, value_from_model, method_tier_from_model, run_model, run_model_from_node
+)
+from hestia_earth.validation.utils import (
+    update_error_path, _filter_list_errors, _next_error, _value_average, is_number,
+    find_linked_node, _is_before_today,
+    _list_except_item, _dict_without_key, hash_dict, _value_range_error,
+    group_blank_nodes
+)
+
+
+CROP_SITE_TYPE = [
+    SiteSiteType.CROPLAND.value,
+    SiteSiteType.GLASS_OR_HIGH_ACCESSIBLE_COVER.value
+]
+OTHER_MODEL_ID = 'otherModel'
 
 
 def validate_properties_same_length(node: dict, list_key: str, prop_key: str, prop_keys: list):
@@ -32,7 +46,7 @@ def validate_properties_same_length(node: dict, list_key: str, prop_key: str, pr
 
 
 def validate_date_lt_today(node: dict, key: str):
-    date = _get_dict_key(node, key)
+    date = get_dict_key(node, key)
     return date is None or _is_before_today(date) or {
         'level': 'error',
         'dataPath': f".{key}",
@@ -51,18 +65,28 @@ def validate_list_date_lt_today(node: dict, list_key: str, node_keys: list):
     return _filter_list_errors(flatten(map(validate, enumerate(node.get(list_key, [])))))
 
 
-def is_date_after(min_date: str, date: str):
+def is_date_after(min_date: str, date: str, strict: bool = True):
     return min_date is None or date is None or (
         len(min_date) <= 7 and len(date) <= 7 and date >= min_date
-    ) or date > min_date
+    ) or (
+        date > min_date if strict else date >= min_date
+    )
 
 
-def validate_list_dates_after(node: dict, node_key: str, list_key: str, list_key_fields: list[str]):
+def is_date_equal(date1: str, date2: str, validate_year_only: bool = False):
+    date1 = safe_parse_date(date1)
+    date2 = safe_parse_date(date2)
+    return (
+        date1.year == date2.year if validate_year_only else date1 == date2
+    ) if all([date1, date2]) else False
+
+
+def validate_list_dates_after(node: dict, node_key: str, list_key: str, list_key_fields: list):
     min_date = node.get(node_key)
 
     def validate_field_list(blank_node: dict, index: int, field: str, field_index: int):
         date = blank_node.get(field)[field_index]
-        return is_date_after(min_date, date) or {
+        return is_date_after(min_date, date, False) or {
             'level': 'warning',
             'dataPath': f".{list_key}[{index}].{field}[{field_index}]",
             'message': f"must be greater than {node.get('type', node.get('@type'))} {node_key}"
@@ -73,7 +97,7 @@ def validate_list_dates_after(node: dict, node_key: str, list_key: str, list_key
         return [
             validate_field_list(blank_node, index, field, field_index) for field_index in range(0, len(date))
         ] if isinstance(date, list) else (
-            is_date_after(min_date, date) or {
+            is_date_after(min_date, date, False) or {
                 'level': 'warning',
                 'dataPath': f".{list_key}[{index}].{field}",
                 'message': f"must be greater than {node.get('type', node.get('@type'))} {node_key}"
@@ -124,15 +148,19 @@ def validate_list_dates_length(node: dict, list_key: str):
     return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
 
 
-def _is_value_below(value1, value2):
+def is_value_below(value1, value2):
     compare_lists = isinstance(value1, list) and isinstance(value2, list)
     return any([value1 is None, value2 is None]) or (
-        _is_list_value_below(value1, value2) if compare_lists else value1 <= value2
+        _is_list_value_below(value1, value2) if compare_lists else any([
+            # allow 1% of rounding error
+            value1 <= value2 * 1.01,
+            Decimal(str(value1)) <= Decimal(str(value2))
+        ])
     )
 
 
 def _is_list_value_below(list1: list, list2: list):
-    def compare_enum(index: int): return _is_value_below(list1[index], list2[index])
+    def compare_enum(index: int): return is_value_below(list1[index], list2[index])
 
     return len(list1) != len(list2) or \
         next((x for x in list(map(compare_enum, range(len(list1)))) if x is not True), True) is True
@@ -145,10 +173,14 @@ def validate_list_value_between_min_max(node: dict, list_key: str):
         max = blank_node.get('max')
         value = blank_node.get('value')
 
-        return all([_is_value_below(value, max), _is_value_below(min, value)]) or {
+        return all([is_value_below(value, max), is_value_below(min, value)]) or {
             'level': 'error',
             'dataPath': f".{list_key}[{index}].value",
-            'message': 'must be between min and max'
+            'message': 'must be between min and max',
+            'params': {
+                'min': min,
+                'max': max
+            }
         }
 
     return _next_error(list(map(validate, enumerate(node.get(list_key, [])))))
@@ -159,7 +191,7 @@ def validate_list_min_below_max(node: dict, list_key: str):
         index, blank_node = values
         min = blank_node.get('min')
         max = blank_node.get('max')
-        return _is_value_below(min, max) or {
+        return is_value_below(min, max) or {
             'level': 'error',
             'dataPath': f".{list_key}[{index}].max",
             'message': 'must be greater than min'
@@ -174,8 +206,8 @@ def validate_list_min_max_lookup(node: dict, list_key: list, list_key_field='val
         term_id = blank_node.get('term', {}).get('@id')
         term_type = blank_node.get('term', {}).get('termType')
         lookup = download_lookup(f"{term_type}.csv")
-        mininum = safe_parse_float(get_table_value(lookup, 'termid', term_id, 'minimum'), None)
-        maximum = safe_parse_float(get_table_value(lookup, 'termid', term_id, 'maximum'), None)
+        mininum = safe_parse_float(get_table_value(lookup, 'termid', term_id, column_name('minimum')), None)
+        maximum = safe_parse_float(get_table_value(lookup, 'termid', term_id, column_name('maximum')), None)
         value = _value_average(blank_node, None, list_key_field)
         error = _value_range_error(value, mininum, maximum) if value is not None else False
         return error is False or ({
@@ -193,7 +225,7 @@ def validate_list_min_max_lookup(node: dict, list_key: list, list_key_field='val
 
 def validate_nodes_duplicates(node: dict, node_by_hash: dict):
     node_without_id = _dict_without_key(node, 'id')
-    key = _hash_dict(node_without_id)
+    key = hash_dict(node_without_id)
     duplicates = _list_except_item(node_by_hash.get(key, []), node)
     return [next(
         ({
@@ -207,7 +239,7 @@ def validate_nodes_duplicates(node: dict, node_by_hash: dict):
 
 def validate_list_duplicate_values(node: dict, list_key: str, prop: str, value: str):
     values = node.get(list_key, [])
-    duplicates = list(filter(lambda v: _get_dict_key(v, prop) == value, values))
+    duplicates = list(filter(lambda v: get_dict_key(v, prop) == value, values))
     return len(duplicates) < 2 or {
         'level': 'error',
         'dataPath': f".{list_key}[{values.index(duplicates[1])}].{prop}",
@@ -216,13 +248,13 @@ def validate_list_duplicate_values(node: dict, list_key: str, prop: str, value:
 
 
 def validate_list_term_percent(node: dict, list_key: str):
-    def soft_validate(index: int, value): return (_is_number(value) and 0 < value and value <= 1) and {
+    def soft_validate(index: int, value): return (is_number(value) and 0 < value and value <= 1) and {
         'level': 'warning',
         'dataPath': f".{list_key}[{index}].value",
         'message': 'may be between 0 and 100'
     }
 
-    def hard_validate(index: int, value): return (_is_number(value) and 0 <= value and value <= 100) or {
+    def hard_validate(index: int, value): return (is_number(value) and 0 <= value and value <= 100) or {
         'level': 'error',
         'dataPath': f".{list_key}[{index}].value",
         'message': 'should be between 0 and 100 (percentage)'
@@ -238,6 +270,66 @@ def validate_list_term_percent(node: dict, list_key: str):
     return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
 
 
+def valid_list_sum(blank_nodes: list):
+    values = [_value_average(p, default=None) for p in blank_nodes]
+    values_number = list(filter(is_number, values))
+    is_valid = len(values) == len(values_number)
+    return list_sum(values_number), is_valid
+
+
+def validate_list_sum_100_percent(node: dict, list_key: str):
+    def validate(values: list):
+        term_ids = [v['node'].get('term', {}).get('@id') for v in values]
+        total_value, valid_sum = valid_list_sum([v['node'] for v in values])
+        blank_node = values[0]
+        min_value = 99.5
+        max_value = 100.5
+        sum_equal_100 = blank_node.get('sumIs100Group')
+        valid = all([
+            total_value <= max_value,
+            not sum_equal_100 or total_value >= min_value
+        ])
+        return valid or [
+            {
+                'level': 'error',
+                'dataPath': f".{list_key}[{value.get('index')}]",
+                'message': f"value should sum to {'' if sum_equal_100 else 'maximum '}100 across all values",
+                'params': {
+                    'termIds': term_ids,
+                    'sum': total_value,
+                    'max': max_value
+                } | ({'min': min_value} if sum_equal_100 else {})
+            } for value in values
+        ]
+
+    groupped_values = group_blank_nodes(enumerate(node.get(list_key, []))).values()
+    return _filter_list_errors(flatten(map(validate, groupped_values)))
+
+
+def validate_list_percent_requires_value(node: dict, list_key: str, term_types: List[TermTermType] = []):
+    term_types_str = [t.value for t in term_types]
+
+    def validate(values: tuple):
+        index, blank_node = values
+        term = blank_node.get('term', {})
+        validate_value = all([
+            term.get('termType') in term_types_str,
+            term.get('units', '').startswith('%')
+        ])
+        value = blank_node.get('value', [])
+        return not validate_value or len(value) > 0 or {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}]",
+            'message': "should have required property 'value'",
+            'params': {
+                'term': term,
+                'missingProperty': 'value'
+            }
+        }
+
+    return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
+
+
 def validate_is_region(node: dict, region_key='region'):
     region_id = node.get(region_key, {}).get('@id', '')
     level = id_to_level(region_id)
@@ -272,84 +364,55 @@ def validate_country(node: dict):
     }
 
 
-def need_validate_coordinates(node: dict): return is_enabled() and 'latitude' in node and 'longitude' in node
+def need_validate_coordinates(node: dict): return gee_is_enabled() and 'latitude' in node and 'longitude' in node
 
 
-def validate_coordinates(node: dict, region_key='region'):
+def validate_coordinates(node: dict):
     latitude = node.get('latitude')
     longitude = node.get('longitude')
     country = node.get('country', {})
-    region = node.get(region_key)
+    region = node.get('region')
     gadm_id = region.get('@id') if region else country.get('@id')
-    id = get_region_id(gadm_id, latitude=latitude, longitude=longitude)
+    id = get_region_id(node)
     return gadm_id == id or {
         'level': 'error',
-        'dataPath': f".{region_key}" if region else '.country',
+        'dataPath': '.region' if region else '.country',
         'message': 'does not contain latitude and longitude',
         'params': {
-            'gadmId': id
+            'current': gadm_id,
+            'expected': id,
+            'distance': get_region_distance(gadm_id, latitude=latitude, longitude=longitude)
         }
     }
 
 
-def need_validate_area(node: dict): return 'area' in node and 'boundary' in node
+def need_validate_area(node: dict):
+    return all(['area' in node, 'boundary' in node, 'boundaryArea' in node])
 
 
 def validate_area(node: dict):
     threshold = 0.05
-
-    try:
-        value = round(node.get('area'), 1)
-        expected_value = get_geojson_area(node.get('boundary'))
-        delta = value_difference(value, expected_value) if expected_value else 0
-        return delta < threshold or {
-            'level': 'warning',
-            'dataPath': '.area',
-            'message': 'should be equal to boundary',
-            'params': {
-                'current': value,
-                'expected': expected_value,
-                'delta': delta * 100,
-                'threshold': threshold
-            }
-        }
-    except KeyError:
-        # if getting the geojson fails, the geojson format is invalid
-        # and the schema validation step will detect it
-        return True
-
-
-def validate_area_size(node: dict):
-    area = node.get('area', 0) / 100
-    return area < MAX_AREA_SIZE or {
+    value = round(node.get('area', 0), 1)
+    expected_value = round(node.get('boundaryArea', 0), 1)
+    delta = value_difference(value, expected_value) if expected_value else 0
+    return delta < threshold or {
         'level': 'warning',
         'dataPath': '.area',
-        'message': 'should be lower than max size',
+        'message': 'should be equal to boundary',
         'params': {
-            'current': area,
-            'expected': MAX_AREA_SIZE
+            'current': value,
+            'expected': expected_value,
+            'delta': delta * 100,
+            'threshold': threshold
         }
     }
 
 
-def need_validate_boundary_size(node: dict):
-    return all([
-        is_enabled(),
-        not need_validate_coordinates(node),
-        'boundary' in node
-    ])
-
-
-def validate_boundary_size(node: dict):
-    boundary = node.get('boundary')
-    try:
-        # get_boundary_size might throw error is geometry has too many edges
-        area = get_boundary_size(boundary) if boundary else 0
-    except Exception:
-        area = 0
+def validate_boundary_area(node: dict):
+    area = node.get('boundaryArea', 0) / 100
     return area < MAX_AREA_SIZE or {
         'level': 'warning',
-        'dataPath': '.boundary',
+        'dataPath': '.boundaryArea',
         'message': 'should be lower than max size',
         'params': {
             'current': area,
@@ -360,9 +423,9 @@ def validate_boundary_size(node: dict):
 
 def need_validate_region_size(node: dict):
     return all([
-        is_enabled(),
+        gee_is_enabled(),
         not need_validate_coordinates(node),
-        not need_validate_boundary_size(node),
+        'boundaryArea' not in node,
         'region' in node or 'country' in node
     ])
 
@@ -371,8 +434,9 @@ def validate_region_size(node: dict):
     region_id = node.get('region', node.get('country', {})).get('@id')
     region = download_hestia(region_id) if region_id else {}
     try:
+        from hestia_earth.earth_engine.gadm import get_size_km2
         # get_region_size might throw error is geometry has too many edges
-        area = region.get('area', get_region_size(region_id) if region_id else None) or 0
+        area = region.get('area', get_size_km2(region_id) if region_id else None) or 0
     except Exception:
         area = 0
     return area < MAX_AREA_SIZE or {
@@ -411,7 +475,7 @@ def validate_empty_fields(node: dict):
 
 
 def validate_linked_source_privacy(node: dict, key: str, node_map: dict = {}):
-    related_source = _find_linked_node(node_map, node.get(key, {}))
+    related_source = find_linked_node(node_map, node.get(key, {}))
     node_privacy = node.get('dataPrivate')
     related_source_privacy = related_source.get('dataPrivate') if related_source else None
     return related_source_privacy is None or node_privacy == related_source_privacy or {
@@ -491,22 +555,35 @@ def _parse_node_value(node: dict):
     )
 
 
-def _validate_list_model(node: dict, list_key: str, max_delta: float = 0.05):
+def _get_term_recalculated_max_delta(term: dict):
+    term_id = term.get('@id')
+    col_name = 'valueToleranceToHestiaRecalculatedValue'
+    return safe_parse_float(
+        get_table_value(download_lookup('emission.csv'), 'termid', term_id, column_name(col_name)),
+        5
+    ) / 100
+
+
+def _validate_list_model(node: dict, list_key: str):
     def validate(values: tuple):
         index, blank_node = values
+        term = blank_node.get('term', {})
+        max_delta = _get_term_recalculated_max_delta(term)
         try:
+            method_tier = blank_node.get('methodTier')
             value = _parse_node_value(blank_node)
             # skip validation if `value` is not set
             result = run_model_from_node(blank_node, node) if value is not None else None
-            expected_value = _value_from_model(result) if result else 0
+            expected_value = value_from_model(result) if result else 0
+            expected_method_tier = method_tier_from_model(result)
             delta = value_difference(value, expected_value)
-            return delta < max_delta or {
+            return method_tier != expected_method_tier or delta < max_delta or {
                 'level': 'error',
                 'dataPath': f".{list_key}[{index}].value",
                 'message': 'the value provided is not consistent with the model result',
                 'params': {
                     'model': blank_node.get('methodModel', {}),
-                    'term': blank_node.get('term', {}),
+                    'term': term,
                     'current': value,
                     'expected': expected_value,
                     'delta': delta * 100,
@@ -523,6 +600,7 @@ def validate_list_model(node: dict, list_key: str) -> list:
     Validates a list using the engine models.
     This method will go through every element of the list and run the model that matches the
     `methodModel` and `term.@id` on the element.
+    Note: if the `methodTier` returned is different than the reported one, the result will be ignored.
 
     Parameters
     ----------
@@ -536,10 +614,9 @@ def validate_list_model(node: dict, list_key: str) -> list:
     list
         List of errors from the models or `True` if no errors.
     """
-    run = os.getenv('VALIDATE_MODELS', 'true') == 'true'
-    nodes = node.get(list_key, [])
+    nodes = node.get(list_key, []) if models_is_enabled() else []
     with ThreadPoolExecutor() as executor:
-        errors = list(executor.map(_validate_list_model(node, list_key), enumerate(nodes))) if run else []
+        errors = list(executor.map(_validate_list_model(node, list_key), enumerate(nodes)))
     return _filter_list_errors(errors)
 
 
@@ -549,18 +626,22 @@ def _reset_completeness(node: dict):
     return {**node, 'completeness': completeness}
 
 
+def _get_model_from_result(result: dict):
+    return result.get('methodModel', result.get('model')) if result else None
+
+
 def _validate_list_model_config(node: dict, list_key: str, conf: dict):
     def validate_model(term: dict, value: float, index: int, model_conf: dict):
         node_run = _reset_completeness(node) if model_conf.get('resetDataCompleteness', False) else node
         expected_result = run_model(model_conf['model'], term.get('@id'), node_run)
-        expected_value = _value_from_model(expected_result)
+        expected_value = value_from_model(expected_result)
         delta = value_difference(value, expected_value)
         return delta < model_conf['delta'] or {
             'level': model_conf.get('level', 'error'),
             'dataPath': f".{list_key}[{index}].value",
             'message': 'the value provided is not consistent with the model result',
             'params': {
-                'model': expected_result[0].get('methodModel', {}),
+                'model': _get_model_from_result(expected_result[0]),
                 'term': term,
                 'current': value,
                 'expected': expected_value,
@@ -602,8 +683,58 @@ def validate_list_model_config(node: dict, list_key: str, conf: dict):
     list
         List of errors from the models or `True` if no errors.
     """
-    run = os.getenv('VALIDATE_MODELS', 'true') == 'true'
-    nodes = node.get(list_key, [])
+    nodes = node.get(list_key, []) if models_is_enabled() else []
     with ThreadPoolExecutor() as executor:
-        errors = list(executor.map(_validate_list_model_config(node, list_key,  conf), enumerate(nodes))) if run else []
+        errors = list(executor.map(_validate_list_model_config(node, list_key,  conf), enumerate(nodes)))
     return _filter_list_errors(errors)
+
+
+def _unique_term_grouping(term_id: str):
+    # TODO: use a lookup instead
+    return re.split(
+        r'(Kg|Liveweight|ColdCarcassWeight|ColdDressedCarcassWeight|ReadyToCookWeight)', term_id
+    )[0] if term_id else None
+
+
+def validate_duplicated_term_units(node: dict, list_key: str, term_types: List[TermTermType]):
+    def term_ids_mapper(prev: dict, curr: dict):
+        term = curr.get('term', {})
+        term_id = term.get('@id')
+        term_id_suffix = _unique_term_grouping(term_id)
+        prev[term_id_suffix] = prev.get(term_id_suffix, []) + [term.get('units')]
+        return prev
+
+    blank_nodes = node.get(list_key, [])
+    term_ids_to_units = reduce(term_ids_mapper, filter_list_term_type(blank_nodes, term_types), {})
+
+    def validate(values: tuple):
+        index, blank_node = values
+        term = blank_node.get('term', {})
+        term_id = term.get('@id')
+        term_id_suffix = _unique_term_grouping(term_id)
+        units = term_ids_to_units.get(term_id_suffix, [])
+        return len(units) <= 1 or {
+            'level': 'warning',
+            'dataPath': f".{list_key}[{index}].term",
+            'message': 'should not use identical terms with different units',
+            'params': {
+                'term': term,
+                'units': units
+            }
+        }
+
+    return _filter_list_errors(map(validate, enumerate(blank_nodes)))
+
+
+def validate_other_model(node: dict, list_key: str):
+    def validate(values: tuple):
+        index, blank_node = values
+        term = blank_node.get('methodModel', {})
+        term_id = term.get('@id')
+        return term_id != OTHER_MODEL_ID or bool(blank_node.get('methodModelDescription')) or {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}].methodModel",
+            'message': 'is required when using other model'
+        }
+
+    return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
