@@ -8,88 +8,105 @@ from hestia_earth.validation.validators.shared import is_value_different
 from .practice import validate_excretaManagement
 
 
-def _validate_previous_term(transformations: list, index: int):
-    transformation = transformations[index]
-    indexes = range(len(transformations))
+def _previous_transformation(cycle: dict, list_key: str, transformation: dict, index: int):
+    tr_id = transformation.get('previousTransformationId')
+    transformations = cycle.get(list_key, [])
+    # previous transformation must be before the current transformation index
+    return next(
+        (transformations[i] for i in reversed(range(0, min(index, len(transformations))))
+         if transformations[i].get('transformationId') == tr_id and i < index),
+        None
+    )
 
-    def _term_index(term_id: str, max_index: int):
-        return next((i for i in indexes if transformations[i].get('term', {}).get('@id') == term_id), max_index)
 
-    term_id = transformation.get('previousTransformationTerm', {}).get('@id')
-    return term_id is None or _term_index(term_id, index) < index or {
+def _validate_previous_term(cycle: dict, list_key: str, transformation: dict, index: int):
+    previous_transformation = _previous_transformation(cycle, list_key, transformation, index)
+    tr_id = transformation.get('previousTransformationId')
+    return not tr_id or previous_transformation is not None or {
         'level': 'error',
-        'dataPath': f".transformations[{index}].previousTransformationTerm",
+        'dataPath': f".{list_key}[{index}].previousTransformationId",
         'message': 'must point to a previous transformation in the list'
     }
 
 
-def _validate_previous_product_value(transformations: list, index: int):
-    transformation = transformations[index]
-    share = transformation.get('transformedShare', 100)
+def _cycle_has_product(cycle: dict, input: dict):
+    term_id = input.get('term', {}).get('@id')
+    return find_term_match(cycle.get('products', []), term_id, None) is not None
+
+
+def _validate_previous_input(cycle: dict, list_key: str, transformation: dict, index: int):
+    has_previous_transformation = transformation.get('previousTransformationId') is not None
     inputs = transformation.get('inputs', [])
-    previous_transformation = transformations[index - 1]
-    products = previous_transformation.get('products', [])
+
+    def validate_in_cycle():
+        return any([
+            len(cycle.get('products', [])) == 0,
+            len(inputs) == 0
+        ]) or any([_cycle_has_product(cycle, i) for i in inputs]) or {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}]",
+            'message': 'at least one Input must be a Product of the Cycle'
+        }
+
+    def validate_in_previous_transformation():
+        previous_transformation = _previous_transformation(cycle, list_key, transformation, index)
+        return not previous_transformation or any([
+            len(previous_transformation.get('products', [])) == 0,
+            len(inputs) == 0
+        ]) or any([_cycle_has_product(previous_transformation, i) for i in inputs]) or {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}]",
+            'message': 'at least one Input must be a Product of the previous Transformation'
+        }
+
+    return validate_in_previous_transformation() if has_previous_transformation else validate_in_cycle()
+
+
+def _validate_previous_product_value(cycle: dict, list_key: str, transformation: dict, index: int):
+    share = transformation.get('transformedShare')
+    inputs = transformation.get('inputs', [])
+    previous_transformation = _previous_transformation(cycle, list_key, transformation, index)
+    products = (previous_transformation or cycle).get('products', [])
 
     def validate_input(input_index: int):
-        input = list_sum(inputs[input_index].get('value', [0]))
-        product = list_sum(find_term_match(products, inputs[input_index].get('term', {}).get('@id')).get('value', [0]))
-        return product == 0 or not is_value_different(product, input * share / 100, 0.01) or {
+        input = list_sum(inputs[input_index].get('value', []), None)
+        term_id = inputs[input_index].get('term', {}).get('@id')
+        product = list_sum(find_term_match(products, term_id).get('value', []), None)
+        return any([not input, not product]) or not is_value_different(input, product * share / 100, 0.01) or {
             'level': 'error',
             'dataPath': f".transformations[{index}].inputs[{input_index}].value",
             'message': 'must be equal to previous product multiplied by the share'
         }
 
-    return len(products) == 0 or _filter_list_errors(flatten(map(validate_input, range(len(inputs)))))
+    return any([
+        len(products) == 0,
+        share is None
+    ]) or _filter_list_errors(flatten(map(validate_input, range(len(inputs)))))
 
 
-def validate_previous_transformation(transformations: list):
-    def validate(index: int):
-        return list(map(lambda func: func(transformations, index), [
+def validate_previous_transformation(cycle: dict, list_key: str = 'transformations'):
+    def validate(values: tuple):
+        index, transformation = values
+        return _filter_list_errors(map(lambda func: func(cycle, list_key, transformation, index), [
             _validate_previous_term,
+            _validate_previous_input,
             _validate_previous_product_value
         ]))
 
-    return _filter_list_errors(flatten(map(validate, range(1, len(transformations)))))
+    return _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
 
 
-def validate_first_transformation_fields(transformations: list):
-    tr = transformations[0] if len(transformations) > 0 else None
-
-    def validate(field: str):
-        return tr.get(field) is None or {
-            'level': 'error',
-            'dataPath': f".transformations[0].{field}",
-            'message': 'must not be set on the first transformation'
-        }
-
-    return not tr or _filter_list_errors(map(validate, ['previousTransformationTerm', 'transformedShare']))
-
-
-def validate_first_transformation_input(cycle: dict, transformations: list):
-    tr = transformations[0] if len(transformations) > 0 else None
-
-    def cycle_has_product(input: dict):
-        term_id = input.get('term', {}).get('@id')
-        return find_term_match(cycle.get('products', []), term_id, None) is not None
-
-    return not tr or any([cycle_has_product(i) for i in tr.get('inputs', [])]) or {
-        'level': 'error',
-        'dataPath': '.transformations[0]',
-        'message': 'at least one Input must be a Product of the Cycle'
-    }
-
-
-def validate_transformation_excretaManagement(transformations: list):
+def validate_transformation_excretaManagement(cycle: dict, list_key: str = 'transformations'):
     def validate(values: tuple):
         index, transformation = values
         practices = transformation.get('practices', []) + [{'term': transformation.get('term')}]
         error = validate_excretaManagement(transformation, practices)
-        return error is True or update_error_path(error, 'transformations', index)
+        return error is True or update_error_path(error, list_key, index)
 
-    return _filter_list_errors(map(validate, enumerate(transformations)))
+    return _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
 
 
-def validate_linked_emission(cycle: dict, list_key: str):
+def validate_linked_emission(cycle: dict, list_key: str = 'transformations'):
     emissions = cycle.get('emissions', [])
 
     def validate_emission(transformation_index: int, transformation: dict):
@@ -124,7 +141,7 @@ def _is_generic_excreta(term_id: str): return len((download_hestia(term_id) or {
 
 
 def validate_excreta_inputs_products(transformations: list):
-    def validate_product(transformation_index: int, input_prefix_ids: list[str]):
+    def validate_product(transformation_index: int, input_prefix_ids: list):
         def validate(values: tuple):
             index, product = values
             term = product.get('term', {})
