@@ -18,6 +18,6 @@ def test_validate_lifespan_invalid():
         data = json.load(f)
     assert validate_lifespan(data.get('nodes')) == {
         'level': 'error',
-        'dataPath': '.infrastructure[1].lifespan',
+        'dataPath': '.infrastructure[1].defaultLifespan',
         'message': 'must equal to endDate - startDate in decimal years (~2.6)'
     }
