@@ -11,7 +11,8 @@ class_path = 'hestia_earth.validation.validators.organisation'
 def test_validate_valid(*args):
     with open(f"{fixtures_path}/organisation/valid.json") as f:
         node = json.load(f)
-    assert validate_organisation(node) == [True] * 8
+    results = validate_organisation(node)
+    assert all([r is True for r in results])
 
 
 def test_validate_organisation_dates_valid():
