@@ -1,27 +1,29 @@
 from unittest.mock import patch
 import json
+import os
 
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.product import (
     validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta, validate_primary,
-    validate_product_ha_functional_unit_ha, validate_product_yield
+    validate_product_ha_functional_unit_ha, validate_product_yield, validate_liveAnimal_requires_excreta
 )
 
 
 class_path = 'hestia_earth.validation.validators.product'
+fixtures_folder = os.path.join(fixtures_path, 'product')
 
 
 def test_validate_economicValueShare_valid():
     # no products should be valid
     assert validate_economicValueShare([]) is True
 
-    with open(f"{fixtures_path}/product/economicValueShare/valid.json") as f:
+    with open(f"{fixtures_folder}/economicValueShare/valid.json") as f:
         data = json.load(f)
     assert validate_economicValueShare(data.get('nodes')) is True
 
 
 def test_validate_economicValueShare_invalid():
-    with open(f"{fixtures_path}/product/economicValueShare/invalid.json") as f:
+    with open(f"{fixtures_folder}/economicValueShare/invalid.json") as f:
         data = json.load(f)
     assert validate_economicValueShare(data.get('nodes')) == {
         'level': 'error',
@@ -37,13 +39,13 @@ def test_validate_value_empty_valid():
     # no products should be valid
     assert validate_value_empty([]) is True
 
-    with open(f"{fixtures_path}/product/value/valid.json") as f:
+    with open(f"{fixtures_folder}/value/valid.json") as f:
         data = json.load(f)
     assert validate_value_empty(data.get('nodes')) is True
 
 
 def test_validate_value_empty_warning():
-    with open(f"{fixtures_path}/product/value/value-empty/warning.json") as f:
+    with open(f"{fixtures_folder}/value/value-empty/warning.json") as f:
         data = json.load(f)
     assert validate_value_empty(data.get('nodes')) == {
         'level': 'warning',
@@ -56,13 +58,13 @@ def test_validate_value_0_valid():
     # no products should be valid
     assert validate_value_0([]) is True
 
-    with open(f"{fixtures_path}/product/value/valid.json") as f:
+    with open(f"{fixtures_folder}/value/valid.json") as f:
         data = json.load(f)
     assert validate_value_0(data.get('nodes')) is True
 
 
 def test_validate_value_0_error():
-    with open(f"{fixtures_path}/product/value/value-0/error.json") as f:
+    with open(f"{fixtures_folder}/value/value-0/error.json") as f:
         data = json.load(f)
     assert validate_value_0(data.get('nodes')) == [
         {
@@ -98,17 +100,13 @@ def test_validate_excreta_valid():
     # no products should be valid
     assert validate_excreta({}) is True
 
-    with open(f"{fixtures_path}/product/excreta/valid.json") as f:
-        data = json.load(f)
-    assert validate_excreta(data) is True
-
-    with open(f"{fixtures_path}/product/excreta/valid-no-excreta.json") as f:
+    with open(f"{fixtures_folder}/excreta/valid.json") as f:
         data = json.load(f)
     assert validate_excreta(data) is True
 
 
 def test_validate_excreta_warning():
-    with open(f"{fixtures_path}/product/excreta/warning.json") as f:
+    with open(f"{fixtures_folder}/excreta/warning.json") as f:
         data = json.load(f)
     assert validate_excreta(data) == {
         'level': 'warning',
@@ -117,7 +115,7 @@ def test_validate_excreta_warning():
         'params': {
             'product': {
                 '@type': 'Term',
-                '@id': 'chicken',
+                '@id': 'broilerChicken',
                 'termType': 'liveAnimal'
             },
             'term': {
@@ -133,7 +131,7 @@ def test_validate_excreta_warning():
 
 
 def test_validate_excreta_error():
-    with open(f"{fixtures_path}/product/excreta/error.json") as f:
+    with open(f"{fixtures_folder}/excreta/error.json") as f:
         data = json.load(f)
     assert validate_excreta(data) == {
         'level': 'error',
@@ -142,7 +140,7 @@ def test_validate_excreta_error():
         'params': {
             'product': {
                 '@type': 'Term',
-                '@id': 'chicken',
+                '@id': 'broilerChicken',
                 'termType': 'liveAnimal'
             },
             'term': {
@@ -152,7 +150,7 @@ def test_validate_excreta_error():
                 'units': 'kg N'
             },
             'current': 'excretaCamelsKgN',
-            'expected': ['excretaKgN', 'excretaPoultryKgN']
+            'expected': ['excretaKgN', 'excretaPoultryKgN', 'excretaMixturesKgN']
         }
     }
 
@@ -161,13 +159,13 @@ def test_validate_primary_valid():
     # no products should be valid
     assert validate_primary([]) is True
 
-    with open(f"{fixtures_path}/product/primary/valid.json") as f:
+    with open(f"{fixtures_folder}/primary/valid.json") as f:
         data = json.load(f)
     assert validate_primary(data.get('nodes')) is True
 
 
 def test_validate_primary_error():
-    with open(f"{fixtures_path}/product/primary/invalid.json") as f:
+    with open(f"{fixtures_folder}/primary/invalid.json") as f:
         data = json.load(f)
     assert validate_primary(data.get('nodes')) == {
         'level': 'error',
@@ -180,13 +178,13 @@ def test_validate_product_ha_functional_unit_ha_valid():
     # no products should be valid
     assert validate_product_ha_functional_unit_ha({'products': []}, 'products') is True
 
-    with open(f"{fixtures_path}/product/fu_ha/valid.json") as f:
+    with open(f"{fixtures_folder}/fu_ha/valid.json") as f:
         cycle = json.load(f)
     assert validate_product_ha_functional_unit_ha(cycle, 'products') is True
 
 
 def test_validate_product_ha_functional_unit_ha_error():
-    with open(f"{fixtures_path}/product/fu_ha/invalid.json") as f:
+    with open(f"{fixtures_folder}/fu_ha/invalid.json") as f:
         cycle = json.load(f)
     assert validate_product_ha_functional_unit_ha(cycle, 'products') == {
         'level': 'error',
@@ -212,21 +210,21 @@ def test_validate_product_yield_valid(*args):
     assert validate_product_yield({'products': []}, {}, 'products') is True
 
     # no value on products should be valid
-    with open(f"{fixtures_path}/product/yield/no-value.json") as f:
+    with open(f"{fixtures_folder}/yield/no-value.json") as f:
         cycle = json.load(f)
     assert validate_product_yield(cycle, cycle.get('site')) is True
 
 
 @patch(f"{class_path}.get_post", return_value=(MU, SD))
 def test_validate_product_yield_valid_with_posterior(*args):
-    with open(f"{fixtures_path}/product/yield/valid.json") as f:
+    with open(f"{fixtures_folder}/yield/valid.json") as f:
         cycle = json.load(f)
     assert validate_product_yield(cycle, cycle.get('site')) is True
 
 
 @patch(f"{class_path}.get_post", return_value=(MU, SD))
 def test_validate_product_yield_invalid_with_posterior(*args):
-    with open(f"{fixtures_path}/product/yield/invalid.json") as f:
+    with open(f"{fixtures_folder}/yield/invalid.json") as f:
         cycle = json.load(f)
     assert validate_product_yield(cycle, cycle.get('site')) == {
         'level': 'warning',
@@ -253,7 +251,7 @@ def test_validate_product_yield_invalid_with_posterior(*args):
 @patch(f"{class_path}.get_prior", return_value=(MU, SD))
 @patch(f"{class_path}.get_post", return_value=(None, None))
 def test_validate_product_yield_valid_with_prior_no_posterior(*args):
-    with open(f"{fixtures_path}/product/yield/valid.json") as f:
+    with open(f"{fixtures_folder}/yield/valid.json") as f:
         cycle = json.load(f)
     assert validate_product_yield(cycle, cycle.get('site')) is True
 
@@ -261,7 +259,7 @@ def test_validate_product_yield_valid_with_prior_no_posterior(*args):
 @patch(f"{class_path}.get_prior", return_value=(MU, SD))
 @patch(f"{class_path}.get_post", return_value=(None, None))
 def test_validate_product_yield_invalid_with_prior_no_posterior(*args):
-    with open(f"{fixtures_path}/product/yield/invalid.json") as f:
+    with open(f"{fixtures_folder}/yield/invalid.json") as f:
         cycle = json.load(f)
     assert validate_product_yield(cycle, cycle.get('site')) == {
         'level': 'warning',
@@ -288,6 +286,32 @@ def test_validate_product_yield_invalid_with_prior_no_posterior(*args):
 @patch(f"{class_path}.get_prior", return_value=(None, None))
 @patch(f"{class_path}.get_post", return_value=(None, None))
 def test_validate_product_yield_valid_no_prior_no_posterior(*args):
-    with open(f"{fixtures_path}/product/yield/valid.json") as f:
+    with open(f"{fixtures_folder}/yield/valid.json") as f:
         cycle = json.load(f)
     assert validate_product_yield(cycle, cycle.get('site')) is True
+
+
+@patch(f"{class_path}.get_post", return_value=Exception)
+def test_validate_product_yield_handle_exception(*args):
+    with open(f"{fixtures_folder}/yield/invalid.json") as f:
+        cycle = json.load(f)
+    assert validate_product_yield(cycle, cycle.get('site')) is True
+
+
+def test_validate_liveAnimal_requires_excreta_valid():
+    # no products should be valid
+    assert validate_liveAnimal_requires_excreta({}, 'products') is True
+
+    with open(f"{fixtures_folder}/liveAnimal/excreta/valid.json") as f:
+        data = json.load(f)
+    assert validate_liveAnimal_requires_excreta(data) is True
+
+
+def test_validate_liveAnimal_requires_excreta_invalid():
+    with open(f"{fixtures_folder}/liveAnimal/excreta/invalid.json") as f:
+        data = json.load(f)
+    assert validate_liveAnimal_requires_excreta(data) == {
+        'level': 'error',
+        'dataPath': '.products',
+        'message': 'must add an excreta product with a liveAnimal product'
+    }
