@@ -1,21 +1,48 @@
 from unittest.mock import patch
 import json
+from hestia_earth.schema import TermTermType
 
 from tests.utils import fixtures_path
 from hestia_earth.validation.utils import _group_nodes, _hash_nodes
 from hestia_earth.validation.validators.shared import (
-    validate_dates, validate_list_dates, validate_list_min_below_max, validate_list_min_max_lookup,
-    validate_country, validate_region_in_country, validate_is_region, validate_area, validate_coordinates,
-    need_validate_coordinates, validate_list_term_percent, validate_empty_fields, validate_linked_source_privacy,
-    validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today,
-    value_difference, is_value_different, validate_list_model, validate_list_model_config,
-    validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates, validate_area_size,
-    validate_boundary_size, need_validate_boundary_size, validate_region_size, need_validate_region_size,
-    validate_private_has_source, validate_list_value_between_min_max, validate_list_dates_after
+    validate_dates,
+    validate_list_dates,
+    validate_list_min_below_max,
+    validate_list_min_max_lookup,
+    validate_country,
+    validate_region_in_country,
+    validate_is_region,
+    validate_area,
+    validate_coordinates,
+    need_validate_coordinates,
+    validate_list_term_percent,
+    validate_empty_fields,
+    validate_linked_source_privacy,
+    validate_list_dates_length,
+    validate_date_lt_today,
+    validate_list_date_lt_today,
+    value_difference,
+    is_value_different,
+    validate_list_model,
+    validate_list_model_config,
+    validate_properties_same_length,
+    validate_list_duplicate_values,
+    validate_nodes_duplicates,
+    validate_boundary_area,
+    validate_region_size,
+    need_validate_region_size,
+    validate_private_has_source,
+    validate_list_value_between_min_max,
+    validate_list_dates_after,
+    validate_duplicated_term_units,
+    validate_list_sum_100_percent,
+    validate_list_percent_requires_value,
+    validate_other_model
 )
 from hestia_earth.validation.validators.cycle import PRODUCTS_MODEL_CONFIG
 
 class_path = 'hestia_earth.validation.validators.shared'
+fixtures_folder = f"{fixtures_path}/shared"
 
 
 def test_validate_dates():
@@ -220,7 +247,11 @@ def test_validate_list_value_between_min_max_invalid():
     assert validate_list_value_between_min_max(node, 'list') == {
         'level': 'error',
         'dataPath': '.list[0].value',
-        'message': 'must be between min and max'
+        'message': 'must be between min and max',
+        'params': {
+            'max': 10,
+            'min': 0,
+        }
     }
     node = {
         'list': [{
@@ -232,7 +263,11 @@ def test_validate_list_value_between_min_max_invalid():
     assert validate_list_value_between_min_max(node, 'list') == {
         'level': 'error',
         'dataPath': '.list[0].value',
-        'message': 'must be between min and max'
+        'message': 'must be between min and max',
+        'params': {
+            'max': [10, 20],
+            'min': [1, 10],
+        }
     }
 
 
@@ -240,13 +275,13 @@ def test_validate_list_min_max_lookup_valid():
     # no measurements should be valid
     assert validate_list_min_max_lookup({}, 'measurements') is True
 
-    with open(f"{fixtures_path}/shared/min-max/value-valid.json") as f:
+    with open(f"{fixtures_folder}/min-max/value-valid.json") as f:
         data = json.load(f)
     assert validate_list_min_max_lookup(data, 'measurements') is True
 
 
 def test_validate_list_min_max_lookup_invalid():
-    with open(f"{fixtures_path}/shared/min-max/value-above.json") as f:
+    with open(f"{fixtures_folder}/min-max/value-above.json") as f:
         data = json.load(f)
     assert validate_list_min_max_lookup(data, 'measurements') == {
         'level': 'error',
@@ -254,7 +289,7 @@ def test_validate_list_min_max_lookup_invalid():
         'message': 'should be below 25000.0'
     }
 
-    with open(f"{fixtures_path}/shared/min-max/value-below.json") as f:
+    with open(f"{fixtures_folder}/min-max/value-below.json") as f:
         data = json.load(f)
     assert validate_list_min_max_lookup(data, 'measurements') == {
         'level': 'error',
@@ -355,26 +390,20 @@ def test_validate_is_region_invalid():
 
 
 def test_validate_area_valid():
-    with open(f"{fixtures_path}/shared/area/valid.json") as f:
-        node = json.load(f)
-    assert validate_area(node) is True
-
-    # will return valid if the geojson is malformed
-    del node['boundary']['features'][0]['type']
+    node = {'area': 4, 'boundaryArea': 4}
     assert validate_area(node) is True
 
 
 def test_validate_area_invalid():
-    with open(f"{fixtures_path}/shared/area/invalid.json") as f:
-        node = json.load(f)
+    node = {'area': 4, 'boundaryArea': 5}
     assert validate_area(node) == {
         'level': 'warning',
         'dataPath': '.area',
         'message': 'should be equal to boundary',
         'params': {
-            'current': 4.5,
-            'expected': 13.8,
-            'delta': 67.39,
+            'current': 4,
+            'expected': 5,
+            'delta': 20,
             'threshold': 0.05
         }
     }
@@ -382,26 +411,29 @@ def test_validate_area_invalid():
 
 @patch(f"{class_path}.get_region_id", return_value='GADM-GBR')
 def test_validate_coordinates_valid(*args):
-    with open(f"{fixtures_path}/shared/coordinates/valid.json") as f:
+    with open(f"{fixtures_folder}/coordinates/valid.json") as f:
         node = json.load(f)
     assert validate_coordinates(node) is True
 
 
+@patch(f"{class_path}.get_region_distance", return_value=5)
 @patch(f"{class_path}.get_region_id", return_value='GADM-GBR')
 def test_validate_coordinates_invalid(*args):
-    with open(f"{fixtures_path}/shared/coordinates/invalid.json") as f:
+    with open(f"{fixtures_folder}/coordinates/invalid.json") as f:
         node = json.load(f)
     assert validate_coordinates(node) == {
         'level': 'error',
         'dataPath': '.country',
         'message': 'does not contain latitude and longitude',
         'params': {
-            'gadmId': 'GADM-GBR'
+            'current': 'GADM-FRA',
+            'expected': 'GADM-GBR',
+            'distance': 5
         }
     }
 
 
-@patch(f"{class_path}.is_enabled", return_value=True)
+@patch(f"{class_path}.gee_is_enabled", return_value=True)
 def test_need_validate_coordinates(*args):
     node = {}
     assert not need_validate_coordinates(node)
@@ -412,28 +444,23 @@ def test_need_validate_coordinates(*args):
 
 
 def test_validate_list_term_percent_valid():
-    with open(f"{fixtures_path}/shared/unit-percent/valid.json") as f:
+    with open(f"{fixtures_folder}/unit-percent/valid.json") as f:
         node = json.load(f)
     assert validate_list_term_percent(node, 'measurements') is True
 
 
 def test_validate_list_term_percent_invalid():
-    with open(f"{fixtures_path}/shared/unit-percent/invalid.json") as f:
+    with open(f"{fixtures_folder}/unit-percent/invalid.json") as f:
         node = json.load(f)
     assert validate_list_term_percent(node, 'measurements') == {
-            'level': 'error',
-            'dataPath': '.measurements[0].value',
-            'message': 'should be between 0 and 100 (percentage)'
-        }
-    assert validate_list_term_percent(node, 'practices') == {
-            'level': 'error',
-            'dataPath': '.practices[0].value',
-            'message': 'should be between 0 and 100 (percentage)'
-        }
+        'level': 'error',
+        'dataPath': '.measurements[0].value',
+        'message': 'should be between 0 and 100 (percentage)'
+    }
 
 
 def test_validate_list_term_percent_warning():
-    with open(f"{fixtures_path}/shared/unit-percent/warning.json") as f:
+    with open(f"{fixtures_folder}/unit-percent/warning.json") as f:
         node = json.load(f)
     assert validate_list_term_percent(node, 'measurements') == [{
         'level': 'warning',
@@ -561,8 +588,8 @@ def test_validate_linked_source_privacy_invalid():
     }
 
 
-@patch(f"{class_path}._find_linked_node")
-def test_validate_linked_source_privacy_indexed(mock_find_linked_node):
+@patch(f"{class_path}.find_linked_node")
+def test_validate_linked_source_privacy_indexed(mockfind_linked_node):
     node = {
         'source': {
             '@type': 'Source',
@@ -570,10 +597,10 @@ def test_validate_linked_source_privacy_indexed(mock_find_linked_node):
         },
         'dataPrivate': True
     }
-    mock_find_linked_node.return_value = {'dataPrivate': True}
+    mockfind_linked_node.return_value = {'dataPrivate': True}
     assert validate_linked_source_privacy(node, 'source') is True
 
-    mock_find_linked_node.return_value = {'dataPrivate': False}
+    mockfind_linked_node.return_value = {'dataPrivate': False}
     assert validate_linked_source_privacy(node, 'source') == {
         'level': 'error',
         'dataPath': '.dataPrivate',
@@ -655,21 +682,27 @@ def test_is_value_different():
     assert not is_value_different(110, 100, 0.1)
 
 
-def test_validate_list_model_valid():
+@patch('hestia_earth.models.utils.property.get_node_property', return_value=None)
+def test_validate_list_model_valid(*args):
     # validating Cycle.emissions
-    with open(f"{fixtures_path}/shared/model/emissions/valid.json") as f:
+    with open(f"{fixtures_folder}/model/emissions/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_list_model(cycle, 'emissions') is True
+
+    with open(f"{fixtures_folder}/model/emissions/valid-variable-tolerance.json") as f:
         cycle = json.load(f)
     assert validate_list_model(cycle, 'emissions') is True
 
     # validating ImpactAssessment.impacts
-    with open(f"{fixtures_path}/shared/model/impacts/valid.json") as f:
+    with open(f"{fixtures_folder}/model/impacts/valid.json") as f:
         impact = json.load(f)
     assert validate_list_model(impact, 'impacts') is True
 
 
-def test_validate_list_model_invalid():
+@patch('hestia_earth.models.utils.property.get_node_property', return_value=None)
+def test_validate_list_model_invalid(*args):
     # validating Cycle.emissions
-    with open(f"{fixtures_path}/shared/model/emissions/invalid.json") as f:
+    with open(f"{fixtures_folder}/model/emissions/invalid.json") as f:
         cycle = json.load(f)
     assert validate_list_model(cycle, 'emissions') == {
         'level': 'error',
@@ -697,7 +730,7 @@ def test_validate_list_model_invalid():
     }
 
     # validating ImpactAssessment.impacts
-    with open(f"{fixtures_path}/shared/model/impacts/invalid.json") as f:
+    with open(f"{fixtures_folder}/model/impacts/invalid.json") as f:
         impact = json.load(f)
     assert validate_list_model(impact, 'impacts') == {
         "level": "error",
@@ -727,19 +760,19 @@ def test_validate_list_model_invalid():
 
 def test_validate_list_model_config_valid():
     # validating Cycle.products
-    with open(f"{fixtures_path}/shared/model/products/valid.json") as f:
+    with open(f"{fixtures_folder}/model/products/valid.json") as f:
         data = json.load(f)
     assert validate_list_model_config(data, 'products', PRODUCTS_MODEL_CONFIG) is True
 
     # missing value should skip validation
-    with open(f"{fixtures_path}/shared/model/products/valid-no-value.json") as f:
+    with open(f"{fixtures_folder}/model/products/valid-no-value.json") as f:
         data = json.load(f)
     assert validate_list_model_config(data, 'products', PRODUCTS_MODEL_CONFIG) is True
 
 
 def test_validate_list_model_config_invalid():
     # validating Cycle.products
-    with open(f"{fixtures_path}/shared/model/products/warning.json") as f:
+    with open(f"{fixtures_folder}/model/products/warning.json") as f:
         data = json.load(f)
     assert validate_list_model_config(data, 'products', PRODUCTS_MODEL_CONFIG) == {
         'level': 'warning',
@@ -766,7 +799,7 @@ def test_validate_list_model_config_invalid():
 
 
 def test_validate_properties_same_length_valid():
-    with open(f"{fixtures_path}/shared/properties-same-length/valid.json") as f:
+    with open(f"{fixtures_folder}/properties-same-length/valid.json") as f:
         data = json.load(f)
     assert validate_properties_same_length(data, 'products', 'endDate', ['startDate']) is True
 
@@ -778,7 +811,7 @@ def test_validate_properties_same_length_valid():
 
 
 def test_validate_properties_same_length_invalid():
-    with open(f"{fixtures_path}/shared/properties-same-length/invalid.json") as f:
+    with open(f"{fixtures_folder}/properties-same-length/invalid.json") as f:
         data = json.load(f)
     assert validate_properties_same_length(data, 'products', 'endDate', ['startDate']) == {
         'level': 'error',
@@ -788,13 +821,13 @@ def test_validate_properties_same_length_invalid():
 
 
 def test_validate_list_duplicate_values_valid():
-    with open(f"{fixtures_path}/shared/properties-duplicate-values/valid.json") as f:
+    with open(f"{fixtures_folder}/properties-duplicate-values/valid.json") as f:
         data = json.load(f)
     assert validate_list_duplicate_values(data, 'practices', 'term.termType', 'excretaManagement') is True
 
 
 def test_validate_list_duplicate_values_invalid():
-    with open(f"{fixtures_path}/shared/properties-duplicate-values/invalid.json") as f:
+    with open(f"{fixtures_folder}/properties-duplicate-values/invalid.json") as f:
         data = json.load(f)
     prop = 'term.termType'
     value = 'excretaManagement'
@@ -806,13 +839,13 @@ def test_validate_list_duplicate_values_invalid():
 
 
 def test_validate_nodes_duplicates_valid():
-    with open(f"{fixtures_path}/shared/data-duplicates/valid.json") as f:
+    with open(f"{fixtures_folder}/data-duplicates/valid.json") as f:
         nodes = json.load(f)
     assert validate_nodes_duplicates(nodes[0], _hash_nodes(nodes)) == []
 
 
 def test_validate_nodes_duplicates_invalid():
-    with open(f"{fixtures_path}/shared/data-duplicates/warning.json") as f:
+    with open(f"{fixtures_folder}/data-duplicates/warning.json") as f:
         nodes = json.load(f)
     assert validate_nodes_duplicates(nodes[0], _hash_nodes(nodes)) == [{
         'level': 'warning',
@@ -821,19 +854,19 @@ def test_validate_nodes_duplicates_invalid():
     }]
 
 
-def test_validate_area_size_valid():
+def test_validate_boundary_area_valid():
     # no area => valid
-    assert validate_area_size({}) is True
+    assert validate_boundary_area({}) is True
 
     area = 5000
-    assert validate_area_size({'area': area}) is True
+    assert validate_boundary_area({'boundaryArea': area}) is True
 
 
-def test_validate_area_size_warning():
+def test_validate_boundary_area_warning():
     area = 520000
-    assert validate_area_size({'area': area}) == {
+    assert validate_boundary_area({'boundaryArea': area}) == {
         'level': 'warning',
-        'dataPath': '.area',
+        'dataPath': '.boundaryArea',
         'message': 'should be lower than max size',
         'params': {
             'current': 5200,
@@ -842,41 +875,7 @@ def test_validate_area_size_warning():
     }
 
 
-@patch(f"{class_path}.is_enabled", return_value=True)
-def test_need_validate_boundary_size(*args):
-    node = {}
-    assert not need_validate_boundary_size(node)
-
-    node['boundary'] = 10
-    assert need_validate_boundary_size(node) is True
-
-    node['latitude'] = 10
-    node['longitude'] = 10
-    assert not need_validate_boundary_size(node)
-
-
-@patch(f"{class_path}.get_boundary_size", return_value=2500)
-def test_validate_boundary_size_valid(*args):
-    # no boundary => valid
-    assert validate_boundary_size({}) is True
-    # boundary below max size => valid
-    assert validate_boundary_size({'boundary': True}) is True
-
-
-@patch(f"{class_path}.get_boundary_size", return_value=10000)
-def test_validate_boundary_size_warning(*args):
-    assert validate_boundary_size({'boundary': True}) == {
-        'level': 'warning',
-        'dataPath': '.boundary',
-        'message': 'should be lower than max size',
-        'params': {
-            'current': 10000,
-            'expected': 5000
-        }
-    }
-
-
-@patch(f"{class_path}.is_enabled", return_value=True)
+@patch(f"{class_path}.gee_is_enabled", return_value=True)
 def test_need_validate_region_size(*args):
     node = {}
     assert not need_validate_region_size(node)
@@ -889,7 +888,7 @@ def test_need_validate_region_size(*args):
     assert not need_validate_region_size(node)
 
 
-@patch(f"{class_path}.get_region_size", return_value=2500)
+@patch('hestia_earth.earth_engine.gadm.get_size_km2', return_value=2500)
 @patch(f"{class_path}.download_hestia")
 def test_validate_region_size_valid(mock_download, *args):
     # no region => valid
@@ -904,7 +903,8 @@ def test_validate_region_size_valid(mock_download, *args):
     assert validate_region_size(data) is True
 
 
-@patch(f"{class_path}.get_region_size", return_value=10000)
+@patch('hestia_earth.earth_engine.gadm.get_size_km2', return_value=10000)
+@patch(f"{class_path}.download_hestia", return_value={})
 def test_validate_region_size_warning(*args):
     assert validate_region_size({'country': {'@id': True}}) == {
         'level': 'warning',
@@ -915,3 +915,252 @@ def test_validate_region_size_warning(*args):
             'expected': 5000
         }
     }
+
+
+def test_validate_duplicated_term_units_valid():
+    # no blank nodes should be valid
+    assert validate_duplicated_term_units({}, 'inputs', [TermTermType.ORGANICFERTILISER]) is True
+
+    with open(f"{fixtures_folder}/duplicated-term-units/valid.json") as f:
+        data = json.load(f)
+    assert validate_duplicated_term_units(data, 'inputs', [TermTermType.ORGANICFERTILISER]) is True
+
+
+def test_validate_duplicated_term_units_invalid():
+    with open(f"{fixtures_folder}/duplicated-term-units/invalid-organicFertiliser.json") as f:
+        data = json.load(f)
+    assert validate_duplicated_term_units(data, 'inputs', [TermTermType.ORGANICFERTILISER]) == [
+        {
+            'level': 'warning',
+            'dataPath': '.inputs[0].term',
+            'message': 'should not use identical terms with different units',
+            'params': {
+                'term': {
+                    '@type': 'Term',
+                    '@id': 'bloodMealKgMass',
+                    'termType': TermTermType.ORGANICFERTILISER.value,
+                    'units': 'kg'
+                },
+                'units': ['kg', 'kg N']
+            }
+        },
+        {
+            'level': 'warning',
+            'dataPath': '.inputs[1].term',
+            'message': 'should not use identical terms with different units',
+            'params': {
+                'term': {
+                    '@type': 'Term',
+                    '@id': 'bloodMealKgN',
+                    'termType': TermTermType.ORGANICFERTILISER.value,
+                    'units': 'kg N'
+                },
+                'units': ['kg', 'kg N']
+            }
+        }
+    ]
+
+    with open(f"{fixtures_folder}/duplicated-term-units/invalid-animalProduct.json") as f:
+        data = json.load(f)
+    assert validate_duplicated_term_units(data, 'products', [TermTermType.ANIMALPRODUCT]) == [
+        {
+            'level': 'warning',
+            'dataPath': '.products[0].term',
+            'message': 'should not use identical terms with different units',
+            'params': {
+                'term': {
+                    '@type': 'Term',
+                    '@id': 'meatChickenLiveweight',
+                    'termType': TermTermType.ANIMALPRODUCT.value,
+                    'units': 'kg liveweight'
+                },
+                'units': ['kg liveweight', 'kg cold carcass weight']
+            }
+        },
+        {
+            'level': 'warning',
+            'dataPath': '.products[1].term',
+            'message': 'should not use identical terms with different units',
+            'params': {
+                'term': {
+                    '@type': 'Term',
+                    '@id': 'meatChickenColdCarcassWeight',
+                    'termType': TermTermType.ANIMALPRODUCT.value,
+                    'units': 'kg cold carcass weight'
+                },
+                'units': ['kg liveweight', 'kg cold carcass weight']
+            }
+        }
+    ]
+
+
+def test_validate_list_sum_100_percent_valid():
+    # no practices should be valid
+    cycle = {'practices': []}
+    assert validate_list_sum_100_percent(cycle, 'practices') is True
+
+    with open(f"{fixtures_folder}/list-values-sum-100/practices/total-90.json") as f:
+        cycle = json.load(f)
+    assert validate_list_sum_100_percent(cycle, 'practices') is True
+
+    with open(f"{fixtures_folder}/list-values-sum-100/practices/total-100.json") as f:
+        cycle = json.load(f)
+    assert validate_list_sum_100_percent(cycle, 'practices') is True
+
+    # missing element same depthUpper / depthLower
+    with open(f"{fixtures_folder}/list-values-sum-100/measurements/missing-soil.json") as f:
+        site = json.load(f)
+    assert validate_list_sum_100_percent(site, 'measurements') is True
+
+    # simple no depth
+    with open(f"{fixtures_folder}/list-values-sum-100/measurements/no-depth-valid.json") as f:
+        site = json.load(f)
+    assert validate_list_sum_100_percent(site, 'measurements') is True
+
+
+def test_validate_list_sum_100_percent_invalid():
+    with open(f"{fixtures_folder}/list-values-sum-100/practices/total-110.json") as f:
+        cycle = json.load(f)
+    assert validate_list_sum_100_percent(cycle, 'practices') == [
+        {
+            'level': 'error',
+            'dataPath': '.practices[0]',
+            'message': 'value should sum to maximum 100 across all values',
+            'params': {
+                'sum': 110,
+                'max': 100.5,
+                'termIds': ['residueIncorporated', 'residueLeftOnField']
+            }
+        },
+        {
+            'level': 'error',
+            'dataPath': '.practices[1]',
+            'message': 'value should sum to maximum 100 across all values',
+            'params': {
+                'sum': 110,
+                'max': 100.5,
+                'termIds': ['residueIncorporated', 'residueLeftOnField']
+            }
+        }
+    ]
+
+    # 90% on same depthUpper / depthLower
+    with open(f"{fixtures_folder}/list-values-sum-100/measurements/with-depth-high-value.json") as f:
+        site = json.load(f)
+    assert validate_list_sum_100_percent(site, 'measurements') == [
+        {
+            'level': 'error',
+            'dataPath': '.measurements[1]',
+            'message': 'value should sum to maximum 100 across all values',
+            'params': {
+                'sum': 110,
+                'max': 100.5,
+                'termIds': ['sandContent', 'siltContent', 'clayContent']
+            }
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[2]',
+            'message': 'value should sum to maximum 100 across all values',
+            'params': {
+                'sum': 110,
+                'max': 100.5,
+                'termIds': ['sandContent', 'siltContent', 'clayContent']
+            }
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[3]',
+            'message': 'value should sum to maximum 100 across all values',
+            'params': {
+                'sum': 110,
+                'max': 100.5,
+                'termIds': ['sandContent', 'siltContent', 'clayContent']
+            }
+        }
+    ]
+
+    # remove all depthUpper / depthLower
+    with open(f"{fixtures_folder}/list-values-sum-100/measurements/no-depth-high-value.json") as f:
+        site = json.load(f)
+    assert validate_list_sum_100_percent(site, 'measurements') == [
+        {
+            'level': 'error',
+            'dataPath': '.measurements[0]',
+            'message': 'value should sum to maximum 100 across all values',
+            'params': {
+                'sum': 120,
+                'max': 100.5,
+                'termIds': ['sandContent', 'siltContent', 'clayContent']
+            }
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[1]',
+            'message': 'value should sum to maximum 100 across all values',
+            'params': {
+                'sum': 120,
+                'max': 100.5,
+                'termIds': ['sandContent', 'siltContent', 'clayContent']
+            }
+        },
+        {
+            'level': 'error',
+            'dataPath': '.measurements[2]',
+            'message': 'value should sum to maximum 100 across all values',
+            'params': {
+                'sum': 120,
+                'max': 100.5,
+                'termIds': ['sandContent', 'siltContent', 'clayContent']
+            }
+        }
+    ]
+
+
+_REQUIRES_VALUE_TERM_TYPES = [TermTermType.CROPRESIDUEMANAGEMENT]
+
+
+def test_validate_list_percent_requires_value_valid():
+    # no practices should be valid
+    cycle = {'practices': []}
+    assert validate_list_percent_requires_value(cycle, 'practices', _REQUIRES_VALUE_TERM_TYPES) is True
+
+    with open(f"{fixtures_folder}/list-percent-value/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_list_percent_requires_value(cycle, 'practices', _REQUIRES_VALUE_TERM_TYPES) is True
+
+
+def test_validate_list_percent_requires_value_invalid():
+    with open(f"{fixtures_folder}/list-percent-value/invalid.json") as f:
+        cycle = json.load(f)
+    assert validate_list_percent_requires_value(cycle, 'practices', _REQUIRES_VALUE_TERM_TYPES) == {
+        'level': 'error',
+        'dataPath': '.practices[0]',
+        'message': "should have required property 'value'",
+        'params': {
+            'term': {
+                '@id': 'residueIncorporated',
+                '@type': 'Term',
+                'name': 'Residue incorporated',
+                'termType': 'cropResidueManagement',
+                'units': '%',
+            },
+            'missingProperty': 'value'
+        }
+    }
+
+
+def test_validate_other_model_valid():
+    with open(f"{fixtures_folder}/otherModel/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_other_model(cycle, 'emissions') is True
+
+
+def test_validate_other_model_invalid():
+    with open(f"{fixtures_folder}/otherModel/invalid.json") as f:
+        cycle = json.load(f)
+    assert validate_other_model(cycle, 'emissions') == {
+        'level': 'error',
+        'dataPath': '.emissions[1].methodModel',
+        'message': 'is required when using other model'
+    }
