@@ -4,8 +4,6 @@ from unittest.mock import patch
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.transformation import (
     validate_previous_transformation,
-    validate_first_transformation_fields,
-    validate_first_transformation_input,
     validate_transformation_excretaManagement,
     validate_linked_emission,
     validate_excreta_inputs_products
@@ -17,90 +15,67 @@ fixtures_folder = f"{fixtures_path}/transformation"
 
 def test_validate_previous_transformation_valid():
     # no transformations should be valid
-    assert validate_previous_transformation([]) is True
+    assert validate_previous_transformation({}, 'transformations') is True
 
-    with open(f"{fixtures_folder}/previousTransformationTerm/valid.json") as f:
-        data = json.load(f)
-    assert validate_previous_transformation(data.get('nodes')) is True
+    with open(f"{fixtures_folder}/previousTransformationId/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_previous_transformation(cycle) is True
 
 
 def test_validate_previous_transformation_invalid():
-    with open(f"{fixtures_folder}/previousTransformationTerm/invalid-wrong-order.json") as f:
-        data = json.load(f)
-    assert validate_previous_transformation(data.get('nodes')) == {
+    with open(f"{fixtures_folder}/previousTransformationId/invalid-wrong-order.json") as f:
+        cycle = json.load(f)
+    assert validate_previous_transformation(cycle) == {
         'level': 'error',
-        'dataPath': '.transformations[1].previousTransformationTerm',
+        'dataPath': '.transformations[1].previousTransformationId',
         'message': 'must point to a previous transformation in the list'
     }
 
-    with open(f"{fixtures_folder}/previousTransformationTerm/invalid-no-previous.json") as f:
-        data = json.load(f)
-    assert validate_previous_transformation(data.get('nodes')) == {
+    with open(f"{fixtures_folder}/previousTransformationId/invalid-no-previous.json") as f:
+        cycle = json.load(f)
+    assert validate_previous_transformation(cycle) == {
         'level': 'error',
-        'dataPath': '.transformations[1].previousTransformationTerm',
+        'dataPath': '.transformations[1].previousTransformationId',
         'message': 'must point to a previous transformation in the list'
     }
 
-    with open(f"{fixtures_folder}/previousTransformationTerm/invalid-product-input.json") as f:
-        data = json.load(f)
-    assert validate_previous_transformation(data.get('nodes')) == {
+    with open(f"{fixtures_folder}/previousTransformationId/invalid-product-input.json") as f:
+        cycle = json.load(f)
+    assert validate_previous_transformation(cycle) == {
         'level': 'error',
         'dataPath': '.transformations[1].inputs[0].value',
         'message': 'must be equal to previous product multiplied by the share'
     }
 
-
-def test_validate_first_transformation_fields_valid():
-    # no transformations should be valid
-    assert validate_first_transformation_fields([]) is True
-
-    with open(f"{fixtures_folder}/first-transformation-fields/valid.json") as f:
-        data = json.load(f)
-    assert validate_first_transformation_fields(data.get('nodes')) is True
-
-
-def test_validate_first_transformation_fields_invalid():
-    with open(f"{fixtures_folder}/first-transformation-fields/invalid.json") as f:
-        data = json.load(f)
-    assert validate_first_transformation_fields(data.get('nodes')) == {
-        'level': 'error',
-        'dataPath': '.transformations[0].previousTransformationTerm',
-        'message': 'must not be set on the first transformation'
-    }
-
-
-def validate_first_transformation_input_valid():
-    # no transformations should be valid
-    assert validate_first_transformation_input({}, []) is True
-
-    with open(f"{fixtures_folder}/first-transformation-input/valid.json") as f:
+    with open(f"{fixtures_folder}/previousTransformationId/invalid-previous-input.json") as f:
         cycle = json.load(f)
-    assert validate_first_transformation_fields(cycle, cycle.get('transformations')) is True
-
-
-def test_validate_first_transformation_input_invalid():
-    with open(f"{fixtures_folder}/first-transformation-input/invalid.json") as f:
-        cycle = json.load(f)
-    assert validate_first_transformation_input(cycle, cycle.get('transformations')) == {
-        'level': 'error',
-        'dataPath': '.transformations[0]',
-        'message': 'at least one Input must be a Product of the Cycle'
-    }
+    assert validate_previous_transformation(cycle) == [
+        {
+            'level': 'error',
+            'dataPath': '.transformations[0]',
+            'message': 'at least one Input must be a Product of the Cycle'
+        },
+        {
+            'level': 'error',
+            'dataPath': '.transformations[1]',
+            'message': 'at least one Input must be a Product of the previous Transformation'
+        }
+    ]
 
 
 def test_validate_transformation_excretaManagement_valid():
     # no transformations should be valid
-    assert validate_transformation_excretaManagement([])
+    assert validate_transformation_excretaManagement({}, 'transformations')
 
     with open(f"{fixtures_folder}/excretaManagement/valid.json") as f:
-        data = json.load(f)
-    assert validate_transformation_excretaManagement(data.get('nodes')) is True
+        cycle = json.load(f)
+    assert validate_transformation_excretaManagement(cycle) is True
 
 
 def test_validate_transformation_excretaManagement_invalid():
     with open(f"{fixtures_folder}/excretaManagement/invalid.json") as f:
-        data = json.load(f)
-    assert validate_transformation_excretaManagement(data.get('nodes')) == {
+        cycle = json.load(f)
+    assert validate_transformation_excretaManagement(cycle) == {
         'level': 'error',
         'dataPath': '.transformations[0].practices',
         'message': 'an excreta input is required when using an excretaManagement practice'
