@@ -10,7 +10,7 @@ class_path = 'hestia_earth.validation.validators'
 
 @patch(f"{class_path}.validate_site")
 def test_validate_node_type_validation(mock_validate_site):
-    node = {'type': NodeType.SITE.value}
+    node = {'type': NodeType.SITE.value, 'id': 'id', 'siteType': 'cropland'}
     validate_node()(node)
     mock_validate_site.assert_called_once()
 
